@@ -123,7 +123,7 @@ def input_nb(liste):
     if (inp=="999"):
         return -1
     elif (inp=="000"):
-        os.system('cls' if os.name == 'nt' else "printf '\033c'")
+        #os.system('cls' if os.name == 'nt' else "printf '\033c'")
         try:
             os.system('termux-clipboard-set ""')
         except:
@@ -140,7 +140,7 @@ def input_nb(liste):
         filter=[]
         for elem in liste:
             filter.append(inp.upper() in elem[0].upper())
-        os.system('cls' if os.name == 'nt' else "printf '\033c'")
+        #os.system('cls' if os.name == 'nt' else "printf '\033c'")
         try:
             os.system('termux-clipboard-set ""')
         except:
